# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/lilg/poslilg/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/lilg/poslilg/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Lilg\\Poslilg\\": "packages/lilg/poslilg/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Lilg\Poslilg\Providers\PoslilgServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Poslilg'  => Lilg\Poslilg\Facades\Poslilg::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Lilg\\PoslilgTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Lilg\Poslilg\Providers\PoslilgServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Lilg\Poslilg\Providers\PoslilgServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Lilg\Poslilg\Providers\PoslilgServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/poslilg/{modulename}

**User**

    http://path-to-route-folder/user/poslilg/{modulename}

**Public**

    http://path-to-route-folder/poslilgs


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/poslilg/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/poslilg/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/poslilg/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/poslilg/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/poslilg/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/poslilg/{modulename}/{slug}
    METHOD: GET