<?php

namespace Lilg\Poslilg\Policies;

use Litepie\User\Contracts\UserPolicy;
use Lilg\Poslilg\Models\Kategori;

class KategoriPolicy
{

    /**
     * Determine if the given user can view the kategori.
     *
     * @param UserPolicy $user
     * @param Kategori $kategori
     *
     * @return bool
     */
    public function view(UserPolicy $user, Kategori $kategori)
    {
        if ($user->canDo('poslilg.kategori.view') && $user->isAdmin()) {
            return true;
        }

        return $kategori->user_id == user_id() && $kategori->user_type == user_type();
    }

    /**
     * Determine if the given user can create a kategori.
     *
     * @param UserPolicy $user
     * @param Kategori $kategori
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('poslilg.kategori.create');
    }

    /**
     * Determine if the given user can update the given kategori.
     *
     * @param UserPolicy $user
     * @param Kategori $kategori
     *
     * @return bool
     */
    public function update(UserPolicy $user, Kategori $kategori)
    {
        if ($user->canDo('poslilg.kategori.edit') && $user->isAdmin()) {
            return true;
        }

        return $kategori->user_id == user_id() && $kategori->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given kategori.
     *
     * @param UserPolicy $user
     * @param Kategori $kategori
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Kategori $kategori)
    {
        return $kategori->user_id == user_id() && $kategori->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given kategori.
     *
     * @param UserPolicy $user
     * @param Kategori $kategori
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Kategori $kategori)
    {
        if ($user->canDo('poslilg.kategori.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given kategori.
     *
     * @param UserPolicy $user
     * @param Kategori $kategori
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Kategori $kategori)
    {
        if ($user->canDo('poslilg.kategori.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
