<?php

namespace Lilg\Poslilg\Providers;

use Illuminate\Support\ServiceProvider;

class PoslilgServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'poslilg');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'poslilg');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerPoslilg();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerPoslilg()
    {
        $this->app->bind('poslilg', function($app) {
            return new Poslilg($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Poslilg', 'Lavalite\Poslilg\Facades\Poslilg');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('lilg.poslilg', function ($app) {
            return $this->app->make('Lilg\Poslilg\Poslilg');
        });

                // Bind Kategori to repository
        $this->app->bind(
            'Lilg\Poslilg\Interfaces\KategoriRepositoryInterface',
            \Lilg\Poslilg\Repositories\Eloquent\KategoriRepository::class
        );

        $this->app->register(\Lilg\Poslilg\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Lilg\Poslilg\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and poslilg's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'lilg.poslilg'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakePoslilg::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['lilg.poslilg'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('lilg/poslilg.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/poslilg')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/poslilg')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
